/****************************************************************************
** Meta object code from reading C++ file 'clipboard.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdeclarative-6.29.0/src/qmlcontrols/kquickcontrolsaddons/clipboard.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clipboard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ClipboardE_t {};
} // unnamed namespace

template <> constexpr inline auto Clipboard::qt_create_metaobjectdata<qt_meta_tag_ZN9ClipboardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Clipboard",
        "QML.Element",
        "auto",
        "modeChanged",
        "",
        "QClipboard::Mode",
        "mode",
        "contentChanged",
        "clipboardChanged",
        "m",
        "contentFormat",
        "QVariant",
        "format",
        "clear",
        "content",
        "formats"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(QClipboard::Mode)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'contentChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clipboardChanged'
        QtMocHelpers::SlotData<void(QClipboard::Mode)>(8, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 9 },
        }}),
        // Method 'contentFormat'
        QtMocHelpers::MethodData<QVariant(const QString &) const>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 11, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<QClipboard::Mode>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'content'
        QtMocHelpers::PropertyData<QVariant>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'formats'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Clipboard, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN9ClipboardE[] = {
    QMetaObject::SuperData::link<QClipboard::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Clipboard::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ClipboardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ClipboardE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN9ClipboardE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ClipboardE_t>.metaTypes,
    nullptr
} };

void Clipboard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Clipboard *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<QClipboard::Mode>>(_a[1]))); break;
        case 1: _t->contentChanged(); break;
        case 2: _t->clipboardChanged((*reinterpret_cast<std::add_pointer_t<QClipboard::Mode>>(_a[1]))); break;
        case 3: { QVariant _r = _t->contentFormat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Clipboard::*)(QClipboard::Mode )>(_a, &Clipboard::modeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Clipboard::*)()>(_a, &Clipboard::contentChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QClipboard::Mode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->content(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->formats(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast<QClipboard::Mode*>(_v)); break;
        case 1: _t->setContent(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Clipboard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Clipboard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ClipboardE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Clipboard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Clipboard::modeChanged(QClipboard::Mode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Clipboard::contentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
